@@ -27,6 +27,7 @@
 #include <regex>
 #include <chrono>
 
+#define MAMBA_EMPTY_SHA "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855";
 
 namespace mamba
 {
@@ -59,7 +60,6 @@ namespace mamba
 
     bool is_package_file(const std::string_view& fn);
 
-    void to_human_readable_filesize(std::ostream& o, double bytes, std::size_t precision = 0);
     bool lexists(const fs::path& p);
     bool lexists(const fs::path& p, std::error_code& ec);
     std::vector<fs::path> filter_dir(const fs::path& dir, const std::string& suffix);
@@ -442,6 +442,15 @@ namespace mamba
         return infile;
     }
 
+    bool ensure_comspec_set();
+    std::unique_ptr<TemporaryFile> wrap_call(const fs::path& root_prefix,
+                                             const fs::path& prefix,
+                                             bool dev_mode,
+                                             bool debug_wrapper_scripts,
+                                             const std::vector<std::string>& arguments);
+
+    std::tuple<std::vector<std::string>, std::unique_ptr<TemporaryFile>> prepare_wrapped_call(
+        const fs::path& prefix, const std::vector<std::string>& cmd);
 
 }  // namespace mamba
 
